@@ -51,7 +51,7 @@ our $DELEGATES;         # fill this from $HELPERS on demand
 
 
 __PACKAGE__->export_any(qw(
-    UTILS blessed is_object textlike params self_params plural xprintf
+    UTILS blessed is_object textlike params self_params plural xprintf dotid
 ));
 
 __PACKAGE__->export_fail(\&_export_fail);
@@ -124,6 +124,13 @@ sub xprintf {
     sprintf($format, @_);
 }
 
+
+sub dotid {
+    my $text = shift;       # munge $text to canonical lower case and dotted form
+    $text =~ s/\W+/./g;     # e.g. Foo::Bar ==> Foo.Bar
+    return lc $text;        # e.g. Foo.Bar  ==> foo.bar
+}
+
 sub _debug {
     print STDERR @_;
 }
@@ -282,6 +289,13 @@ suitable for feeding into C<require()>
 
     print module_file('My::Module');     # My/Module.pm
 
+=head2 dotid($text)
+
+The function returns a lower case representation of the text passed as
+an argument with all non-word character sequences replaced with dots.
+
+    print dotid('Foo::Bar');            # foo.bar
+
 =head2 xprintf($format,@args)
 
 A wrapper around C<sprintf()> which provides some syntactic sugar for 
